# Credits

In case you wanted to know who to thank/blame for different features ;)
ORCiD's provided for specificity.

## Concepts and core code development

*   David W. Wright ([0000-0002-5124-8044](https://orcid.org/0000-0002-5124-8044))
*   Robin A. Richardson ([0000-0002-9984-2720](https://orcid.org/0000-0002-9984-2720))
*   Vytautas Jancauskas ([0000-0002-6051-210X](https://orcid.org/0000-0002-6051-210X))

## Statistical methods implementation

*  Quasi Monte Carlo and Polynomial Chaos Expansion - Jalal Lakhlili
*  Stochastic Collocation - Wouter Edeling
*  MCMC - Vytautas Jancauskas ([0000-0002-6051-210X](https://orcid.org/0000-0002-6051-210X))

## Test design implementation

*  Vytautas Jancauskas ([0000-0002-6051-210X](https://orcid.org/0000-0002-6051-210X))

## Execution

* Kubernetes - Vytautas Jancauskas ([0000-0002-6051-210X](https://orcid.org/0000-0002-6051-210X))
* Dask - Vytautas Jancauskas ([0000-0002-6051-210X](https://orcid.org/0000-0002-6051-210X))

## Alpha Testers

*  Robert C. Sinclair
*  Onnie Luk
*  James Suter

## General design discussions

*  Bartosz Bosak
*  David Coster
*  Daan Cromelin
*  Jonathan Feinberg
*  Derek Groen
*  Tomasz Piontek
*  Udo von Toussaint
*  Lourens Veen
